pub enum FileAction {
Create {
path: AbsolutePathOwned,
node: Node,
recursive: bool,
},
Remove {
path: AbsolutePathOwned,
recursive: bool,
},
Modify {
path: AbsolutePathOwned,
modifications: Vec<FileModification>,
},
}Variants
Create
Create a node. Ignored if a node with the same name already exists at path.
Fields

path: AbsolutePathOwnedThe parent to create the node in.
Remove
Remove a node. If a node has children and recusive is set to false nothing will happen.
Modify
Modify a node.